@@ -1,5 +1,5 @@
 package Lingua::Anagrams;
-$Lingua::Anagrams::VERSION = '0.003';
+$Lingua::Anagrams::VERSION = '0.004';
 # ABSTRACT: pure Perl anagram finder
 
 use strict;
@@ -32,6 +32,7 @@ sub _trieify {
     my $words = shift;
     my $base  = [];
     my ( @known, $lowest );
+    my $terminal = [];
     for my $word (@$words) {
         $cleaner->($word);
         next unless length $word;
@@ -46,7 +47,7 @@ sub _trieify {
         }
         _learn( \@known, \@chars );
         push @chars, 0;
-        _add( $base, \@chars );
+        _add( $base, \@chars, $terminal );
     }
     return $base, \@known, $lowest;
 }
@@ -59,10 +60,15 @@ sub _learn {
 }
 
 sub _add {
-    my ( $base, $chars ) = @_;
+    my ( $base, $chars, $terminal ) = @_;
     my $i = shift @$chars;
-    my $next = $base->[$i] //= [];
-    _add( $next, $chars ) if $i;
+    if ($i) {
+        my $next = $base->[$i] //= [];
+        _add( $next, $chars, $terminal );
+    }
+    else {
+        $base->[0] //= $terminal;
+    }
 }
 
 # walk the trie looking for words you can make out of the current character count
@@ -125,8 +131,8 @@ sub anagrams {
     return () unless length $phrase;
     my $counts = _counts($phrase);
     return () unless _all_known($counts);
-    local @jumps   = _jumps($counts);
-    local @indices = _indices($counts);
+    local @jumps      = _jumps($counts);
+    local @indices    = _indices($counts);
     local %cache      = ();
     local %word_cache = ();
     my @anagrams = _anagramize($counts);
@@ -243,7 +249,7 @@ Lingua::Anagrams - pure Perl anagram finder
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
